# MachineTypePrice

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**uid** | **str** |  | 
**machine_type** | **str** |  | 
**commitment_term** | **str** |  | 
**gpu_price_hr** | [**Decimal**](Decimal.md) |  | 
**vcpu_price_hr** | [**Decimal**](Decimal.md) |  | 
**memory_gib_price_hr** | [**Decimal**](Decimal.md) |  | 
**boot_disk_gib_price_hr** | [**Decimal**](Decimal.md) |  | 
**ipv4_price_hr** | [**Decimal**](Decimal.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


